==> flutterskel-0.0.3.tar.gz: lib/widgets/stateful/RawBaseStatefulWidget.dart <==
import 'package:flutter/widgets.dart';
import 'package:flutterskel/configuration/ConfigurationRepository.dart';
import 'package:flutterskel/datasource/DataSource.dart';
import 'package:flutterskel/resources/images/ImageResources.dart';
import 'package:flutterskel/resources/strings/StringsRepository.dart';
import 'package:flutterskel/resources/themes/ThemeRepository.dart';
import 'package:flutterskel/routing/page/PageRouter.dart';
import 'package:flutterskel/routing/url/UrlRouter.dart';
import 'package:flutterskel/userinformation/UserInformationRepository.dart';
import 'package:flutterskel/resources/icons/IconResources.dart';
import 'package:provider/provider.dart';

/// abstract State class
/// This class should only be extended by an abstract class within the app, which fills in all the info except [StateWidget]
/// [StateWidget] should be filled in by the final StatefulWidget class
abstract class RawBaseStatefulWidgetState<
                              StateWidget extends StatefulWidget,
                              Data extends DataSource, URouter extends UrlRouter, PRouter extends PageRouter, Images extends ImageResources,
                              ConfigRepo extends ConfigurationRepository, UserRepo extends UserInformationRepository,
                              StringRepo extends StringsRepository, ThemeRepo extends ThemeRepository,
                              Icons extends IconResources> extends State<StateWidget> {

  Data get dataSource => Provider.of<Data>(context);

  URouter get urlRouter => Provider.of<URouter>(context);

  PRouter get pageRouter => Provider.of<PRouter>(context);

  Images get images => Provider.of<Images>(context);

  ConfigRepo get configuration => Provider.of<ConfigRepo>(context);

  UserRepo get userInformation => Provider.of<UserRepo>(context);

  StringRepo get strings => Provider.of<StringRepo>(context);

  ThemeRepo get themes => Provider.of<ThemeRepo>(context);

  Icons get icons => Provider.of<Icons>(context);
}

==> flutterskel-0.0.5.tar.gz: lib/widgets/stateful/RawBaseStatefulWidget.dart <==
import 'package:flutter/widgets.dart';
import 'package:flutterskel/configuration/ConfigurationRepository.dart';
import 'package:flutterskel/datasource/DataSource.dart';
import 'package:flutterskel/resources/images/ImageResources.dart';
import 'package:flutterskel/resources/strings/StringsRepository.dart';
import 'package:flutterskel/resources/themes/ThemeRepository.dart';
import 'package:flutterskel/resources/themes/ThemeResources.dart';
import 'package:flutterskel/routing/page/PageRouter.dart';
import 'package:flutterskel/routing/url/UrlRouter.dart';
import 'package:flutterskel/userinformation/UserInformationRepository.dart';
import 'package:flutterskel/resources/icons/IconResources.dart';
import 'package:provider/provider.dart';

/// abstract State class
/// This class should only be extended by an abstract class within the app, which fills in all the info except [StateWidget]
/// [StateWidget] should be filled in by the final StatefulWidget class
abstract class RawBaseStatefulWidgetState<
                              StateWidget extends StatefulWidget,
                              Data extends DataSource,
                              URouter extends UrlRouter,
                              PRouter extends PageRouter,
                              Images extends ImageResources,
                              ConfigRepo extends ConfigurationRepository,
                              UserRepo extends UserInformationRepository,
                              StringRepo extends StringsRepository,
                              ThemeRepo extends ThemeRepository,
                              Theme extends ThemeResources,
                              Icons extends IconResources> extends State<StateWidget> {

  Data get dataSource => Provider.of<Data>(context);

  URouter get urlRouter => Provider.of<URouter>(context);

  PRouter get pageRouter => Provider.of<PRouter>(context);

  Images get images => Provider.of<Images>(context);

  ConfigRepo get configuration => Provider.of<ConfigRepo>(context);

  UserRepo get userInformation => Provider.of<UserRepo>(context);

  StringRepo get strings => Provider.of<StringRepo>(context);

  ThemeRepo get themeRepo => Provider.of<ThemeRepo>(context);

  Theme get theme => themeRepo.theme;

  Icons get icons => Provider.of<Icons>(context);
}
